#[repr(u8)]pub enum Apllerr {
DISABLED_OR_NO_ERROR = 0,
ENABLED_AND_ERROR = 1,
}Variants
DISABLED_OR_NO_ERROR = 0
APLL Clock Monitor is disabled or has not detected an error
ENABLED_AND_ERROR = 1
APLL Clock Monitor is enabled and detected an error
Implementations